@@ -1,8 +1,6 @@
 import numbers
 import numpy as np
 import yaml
-import sys
-import random
 
 import pandas as pd
 
@@ -1085,7 +1083,9 @@ class Space(object):
         rng = check_random_state(random_state)
         req_points = []
         if self.is_config_space:
-            confs = self.config_space.sample_configuration(1000)
+            confs = self.config_space.sample_configuration(n_samples)
+            if n_samples == 1:
+                confs = [confs]
             hps_names = self.config_space.get_hyperparameter_names()
             points = []
             for conf in confs:
@@ -1113,10 +1113,7 @@ class Space(object):
                 req_points = unique_points.tolist()
 
             if len(req_points) > 0:
-                sel_req_points = random.choices(
-                    req_points, k=min(len(req_points), n_samples)
-                )
-                return sel_req_points
+                return req_points
             else:
                 return []
         else:
